#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghcide
version:              2.3.0.0
visibility:           public
id:                   ghcide-2.3.0.0-8hzV1WcjE3LJ8SSkOMpWtc
key:                  ghcide-2.3.0.0-8hzV1WcjE3LJ8SSkOMpWtc
license:              Apache-2.0
copyright:            Digital Asset and Ghcide contributors 2018-2020
maintainer:           Ghcide contributors
author:               Digital Asset and Ghcide contributors
homepage:
    https://github.com/haskell/haskell-language-server/tree/master/ghcide#readme

synopsis:             The core of an IDE
description:          A library for building Haskell IDE'\''s on top of the GHC API.
category:             Development
abi:                  2fa5de4e2d64b16807b27167766e7aff
exposed:              True
exposed-modules:
    Control.Concurrent.Strict Development.IDE
    Development.IDE.Core.Actions Development.IDE.Core.Compile
    Development.IDE.Core.Debouncer Development.IDE.Core.FileStore
    Development.IDE.Core.FileUtils
    Development.IDE.Core.IdeConfiguration
    Development.IDE.Core.OfInterest Development.IDE.Core.PluginUtils
    Development.IDE.Core.PositionMapping
    Development.IDE.Core.Preprocessor
    Development.IDE.Core.ProgressReporting
    Development.IDE.Core.RuleTypes Development.IDE.Core.Rules
    Development.IDE.Core.Service Development.IDE.Core.Shake
    Development.IDE.Core.Tracing Development.IDE.Core.UseStale
    Development.IDE.GHC.Compat Development.IDE.GHC.Compat.Core
    Development.IDE.GHC.Compat.Env Development.IDE.GHC.Compat.Iface
    Development.IDE.GHC.Compat.Logger
    Development.IDE.GHC.Compat.Outputable
    Development.IDE.GHC.Compat.Parser
    Development.IDE.GHC.Compat.Plugins Development.IDE.GHC.Compat.Units
    Development.IDE.GHC.Compat.Util Development.IDE.GHC.CoreFile
    Development.IDE.GHC.Error Development.IDE.GHC.Orphans
    Development.IDE.GHC.Util
    Development.IDE.Import.DependencyInformation
    Development.IDE.Import.FindImports
    Development.IDE.LSP.HoverDefinition
    Development.IDE.LSP.LanguageServer
    Development.IDE.LSP.Notifications Development.IDE.LSP.Outline
    Development.IDE.LSP.Server Development.IDE.Main
    Development.IDE.Main.HeapStats Development.IDE.Monitoring.EKG
    Development.IDE.Monitoring.OpenTelemetry Development.IDE.Plugin
    Development.IDE.Plugin.Completions
    Development.IDE.Plugin.Completions.Types Development.IDE.Plugin.HLS
    Development.IDE.Plugin.HLS.GhcIde Development.IDE.Plugin.Test
    Development.IDE.Plugin.TypeLenses Development.IDE.Session
    Development.IDE.Session.Diagnostics Development.IDE.Spans.AtPoint
    Development.IDE.Spans.Common Development.IDE.Spans.Documentation
    Development.IDE.Spans.LocalBindings Development.IDE.Spans.Pragmas
    Development.IDE.Types.Diagnostics Development.IDE.Types.Exports
    Development.IDE.Types.HscEnvEq Development.IDE.Types.KnownTargets
    Development.IDE.Types.Location Development.IDE.Types.Monitoring
    Development.IDE.Types.Options Development.IDE.Types.Shake
    Generics.SYB.GHC Text.Fuzzy.Parallel

hidden-modules:
    Development.IDE.Core.FileExists Development.IDE.GHC.CPP
    Development.IDE.GHC.Warnings
    Development.IDE.Plugin.Completions.Logic
    Development.IDE.Session.VersionCheck Development.IDE.Types.Action

import-dirs:          /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghcide
hs-libraries:         HSghcide-2.3.0.0-8hzV1WcjE3LJ8SSkOMpWtc
depends:
    Diff-1.0-51T9Z3lXl7dCcFt1EsHt5x Glob-0.10.2-LQrDcuK21rJJNr3rG3UOBr
    aeson-2.2.2.0-p30NU7EGMRKoAj5LcAXNN array-0.5.6.0
    async-2.2.6-Cc2ylPSJ9T994nMR0Eaxyq base-4.18.2.1
    base16-bytestring-1.0.2.0-HKNPUjeO8LQ9RSeGAokMwf binary-0.8.9.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-CbvbZydH4uCGBf3Bqda73d
    co-log-core-0.3.2.7-F1O34oOHUJ28GHaQylQqCF containers-0.6.7
    cryptohash-sha1-0.11.101.0-EYRlHYNpqN36EzjsucJ4qd
    data-default-0.7.1.3-6zOkPXxynjr15x05rRaNvG deepseq-1.4.8.1
    dependent-map-0.4.0.1-Lq3bmWHIeLD3UcKWP409I5
    dependent-sum-0.7.2.0-2P5khg6ygR16bcsGg4a3q3 directory-1.3.8.5
    dlist-1.0-F3vtDhl0dJJ2wapcm5Bnp
    enummapset-0.7.3.0-2pLL6S7ZM6HEfe1UbhhFHX exceptions-0.10.7
    extra-1.7.16-J2nH1si97LP2pkcRW1gnIU filepath-1.4.300.1
    fingertree-0.1.6.3-AjtEp1LLvbnIthSmL26CL9
    focus-1.0.3.2-3PwZcYUGxTS7LdMkcL1DNM ghc-9.6.6 ghc-boot-9.6.6
    ghc-boot-th-9.6.6 ghc-check-0.5.0.8-JXHk6yzT9eJLoVskUO3Meo
    ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    ghc-trace-events-0.1.2.10-H26I0MYftT2GE85bySiIsN
    haddock-library-1.11.0-3dXuYnMEYazFk7cvZI8ORZ
    hashable-1.4.7.0-8JCT2FqI0OIc7eryHiY9E
    hie-bios-0.12.0-DxNJ4M2pckRBngSovkQkwI
    hie-compat-0.3.1.2-37lTPgU0jdr1Ufn5QvEKoZ
    hiedb-0.4.3.0-Ko0oMqKlCE3HsM5SK0VCr1
    hls-graph-2.3.0.0-1msln5dYwBzAXqrDhtCn8w
    hls-plugin-api-2.3.0.0-77mjs7RB43bHJjsly5HGud
    implicit-hie-0.1.4.0-3yJhi8EzYz0DrBwH9w2WCa
    implicit-hie-cradle-0.5.0.1-BvW7b9nw2BzCS8NpJe3Dpm
    lens-5.3.5-7MUa280kiW5NfytVlUfpR
    list-t-1.0.5.7-67vvbyEZpEn6RCTxa2joEu
    lsp-2.2.0.0-KqYdVuca5eSIspYKEV6nVH
    lsp-types-2.0.2.0-BlG0C0O79Tw3JN6wlv3g25 mtl-2.3.1
    opentelemetry-0.8.0-LhTWWXgk49mJCpz4ym7fyd
    optparse-applicative-0.18.1.0-2OPlFtvlr5yI8qFRB5F8bn
    parallel-3.2.2.0-4GFGhbl8Ae06nPoqdIyBUD
    prettyprinter-1.7.2-JipenGj1ZXCGzFGneLGC87
    prettyprinter-ansi-terminal-1.1.4-1eYFKNqRJpCEJbcAlUbmrg
    random-1.2.1.3-L4ByjUo9HMh9NaA0HunG5L
    regex-tdfa-1.3.2.5-5Xsa8Nkm5ozG5wMRmCPABC
    row-types-1.0.1.2-8mZe8dnAYrVKiXP9bAhQ4L
    safe-exceptions-0.1.7.4-EJ1HOjDpf87Jv7v1DsVVOt
    sorted-list-0.2.3.1-3OrLrWhBrF41WTmKiIcJqa
    sqlite-simple-0.4.19.0-IuZ0Ce3SMCbLEYdJYMKdFR stm-2.5.1.0
    stm-containers-1.2.1.1-DZXKTVPEu5PCsJMH01hFdU
    syb-0.7.4-6oouIIO3k8DpxFQgfxTIJ text-2.0.2
    text-rope-0.3-EO5ymQqmXhR3J2sULWxVPk time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0
    unliftio-0.2.25.1-5kFyykBV8QLAHqHdpZTooL
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.21-KyMpciGvYH9aykbB6p5Z
    vector-0.13.2.0-pkGAkHyCfVA94J1hIBHJi

haddock-interfaces:   /usr/share/doc/haskell-ghcide/html/ghcide.haddock
haddock-html:         /usr/share/doc/haskell-ghcide/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

